@@ -8,7 +8,7 @@ package Inline::Java ;
 use strict ;
 require 5.006 ;
 
-$Inline::Java::VERSION = '0.49' ;
+$Inline::Java::VERSION = '0.50' ;
 
 
 # DEBUG is set via the DEBUG config
@@ -69,6 +69,7 @@ sub done {
 	shutdown_JVM() ;
 	Inline::Java::debug(1, "exiting with $ec") ;
 	CORE::exit($ec) ;
+	exit($ec) ;
 }
 
 
@@ -131,27 +132,28 @@ sub validate {
 	my $jdk = Inline::Java::get_default_j2sdk() ;
 	my $dbg = $Inline::Java::DEBUG ;
 	my %opts = @_ ;
-	$o->set_option('DEBUG',					$dbg,	'i', 1, \%opts) ;
-	$o->set_option('J2SDK',					$jdk,	's', 1, \%opts) ;
-	$o->set_option('CLASSPATH',				'',		's', 1, \%opts) ;
+	$o->set_option('DEBUG',					$dbg,			'i', 1, \%opts) ;
+	$o->set_option('J2SDK',					$jdk,			's', 1, \%opts) ;
+	$o->set_option('CLASSPATH',				'',				's', 1, \%opts) ;
 
-	$o->set_option('PORT',					-1,		'i', 1, \%opts) ;
-	$o->set_option('STARTUP_DELAY',			15,		'i', 1, \%opts) ;
-	$o->set_option('SHARED_JVM',			0,		'b', 1, \%opts) ;
-	$o->set_option('START_JVM',				1,		'b', 1, \%opts) ;
-	$o->set_option('JNI',					0,		'b', 1, \%opts) ;
-	$o->set_option('EMBEDDED_JNI',			0,		'b', 1, \%opts) ;
+	$o->set_option('HOST',					'localhost',	's', 1, \%opts) ;
+	$o->set_option('PORT',					-1,				'i', 1, \%opts) ;
+	$o->set_option('STARTUP_DELAY',			15,				'i', 1, \%opts) ;
+	$o->set_option('SHARED_JVM',			0,				'b', 1, \%opts) ;
+	$o->set_option('START_JVM',				1,				'b', 1, \%opts) ;
+	$o->set_option('JNI',					0,				'b', 1, \%opts) ;
+	$o->set_option('EMBEDDED_JNI',			0,				'b', 1, \%opts) ;
 
-	$o->set_option('WARN_METHOD_SELECT',	0,		'b', 1, \%opts) ;
-	$o->set_option('STUDY',					undef,	'a', 0, \%opts) ;
-	$o->set_option('AUTOSTUDY',				0,		'b', 1, \%opts) ;
+	$o->set_option('WARN_METHOD_SELECT',	0,				'b', 1, \%opts) ;
+	$o->set_option('STUDY',					undef,			'a', 0, \%opts) ;
+	$o->set_option('AUTOSTUDY',				0,				'b', 1, \%opts) ;
 
-	$o->set_option('EXTRA_JAVA_ARGS',		'',		's', 1, \%opts) ;
-	$o->set_option('EXTRA_JAVAC_ARGS',		'',		's', 1, \%opts) ;
-	$o->set_option('DEBUGGER',				0,		'b', 1, \%opts) ;
+	$o->set_option('EXTRA_JAVA_ARGS',		'',				's', 1, \%opts) ;
+	$o->set_option('EXTRA_JAVAC_ARGS',		'',				's', 1, \%opts) ;
+	$o->set_option('DEBUGGER',				0,				'b', 1, \%opts) ;
 
-	$o->set_option('PRIVATE',				'',		'b', 1, \%opts) ;
-	$o->set_option('PACKAGE',				'',		's', 1, \%opts) ;
+	$o->set_option('PRIVATE',				'',				'b', 1, \%opts) ;
+	$o->set_option('PACKAGE',				'',				's', 1, \%opts) ;
 
 	my @left_overs = keys(%opts) ;
 	if (scalar(@left_overs)){
@@ -181,6 +183,9 @@ sub validate {
 	if (($o->get_java_config('JNI'))&&($o->get_java_config('DEBUGGER'))){
 		croak("You can't invoke the Java debugger ('DEBUGGER' option) in 'JNI' mode") ;
 	}
+	if ((! $o->get_java_config('SHARED_JVM'))&&(! $o->get_java_config('START_JVM'))){
+		croak("Disabling the 'START_JVM' option only makes sense in 'SHARED_JVM' mode") ;
+	}
 
 	if ($o->get_java_config('JNI')){
 		require Inline::Java::JNI ;
@@ -309,6 +314,18 @@ sub build {
 	# it could be relative...
 	my $server_jar = Inline::Java::Portable::get_server_jar() ;
 
+	# We need to add all the previous install dirs to the classpath because
+	# they can access each other.
+	my @prev_install_dirs = () ;
+	foreach my $in (@INLINES){
+		push @prev_install_dirs, File::Spec->catdir($in->get_api('install_lib'), 
+			'auto', $in->get_api('modpname')) ;
+	}
+
+	my $cp = $ENV{CLASSPATH} || '' ;
+	$ENV{CLASSPATH} = Inline::Java::Portable::make_classpath($server_jar, @prev_install_dirs, $o->get_java_config('CLASSPATH')) ;
+	Inline::Java::debug(2, "classpath: $ENV{CLASSPATH}") ;
+
 	# Create the build dir and go there
 	my $build_dir = $o->get_api('build_dir') ;
 	$o->mkpath($build_dir) ;
@@ -344,20 +361,10 @@ sub build {
 		"javac" . Inline::Java::Portable::portable("EXE_EXTENSION")) ;
 		my $redir = Inline::Java::Portable::portable("IO_REDIR") ;
 
-		# We need to add all the previous install dirs to the classpath because
-		# they can access each other.
-		my @prev_install_dirs = () ;
-		foreach my $in (@INLINES){
-			push @prev_install_dirs, File::Spec->catdir($in->get_api('install_lib'), 
-				'auto', $in->get_api('modpname')) ;
-		}
-
-		my $cp = $ENV{CLASSPATH} || '' ;
-		$ENV{CLASSPATH} = Inline::Java::Portable::make_classpath($server_jar, @prev_install_dirs, $o->get_java_config('CLASSPATH')) ;
-		Inline::Java::debug(2, "classpath: $ENV{CLASSPATH}") ;
 		my $args = "-deprecation " . $o->get_java_config('EXTRA_JAVAC_ARGS') ;
+		my $pinstall_dir = Inline::Java::Portable::portable("SUB_FIX_JAVA_PATH", $install_dir) ;
 		my $cmd = Inline::Java::Portable::portable("SUB_FIX_CMD_QUOTES", 
-			"\"$javac\" $args -d \"$install_dir\" $source > cmd.out $redir") ;
+			"\"$javac\" $args -d \"$pinstall_dir\" $source > cmd.out $redir") ;
 		if ($o->get_config('UNTAINT')){
 			($cmd) = $cmd =~ /(.*)/ ;
 		}
@@ -370,8 +377,6 @@ sub build {
 		if ($msg){
 			warn("\n$msg\n") ;
 		}
-		$ENV{CLASSPATH} = $cp ;
-		Inline::Java::debug(2, "classpath: $ENV{CLASSPATH}") ;
 
 		# When we run the commands, we quote them because in WIN32 you need it if
 		# the programs are in directories which contain spaces. Unfortunately, in
@@ -392,6 +397,9 @@ sub build {
 		}
 	}
 
+	$ENV{CLASSPATH} = $cp ;
+	Inline::Java::debug(2, "classpath: $ENV{CLASSPATH}") ;
+
 	# Touch the .jdat file.
 	my $jdat = File::Spec->catfile($install_dir, $o->get_api('modfname') . '.' . $o->get_api('suffix')) ;
 	if (! open(Inline::Java::TOUCH, ">$jdat")){
@@ -474,7 +482,7 @@ sub load {
 		Inline::Java::debug(2, "classpath: $ENV{CLASSPATH}") ;
 
 		my $pc = new Inline::Java::Protocol(undef, $o) ;
-		$pc->AddClassPath(Inline::Java::Portable::portable("SUB_FIX_CLASSPATH", Inline::Java::Portable::get_user_jar())) ;
+		$pc->AddClassPath(Inline::Java::Portable::portable("SUB_FIX_JAVA_PATH", Inline::Java::Portable::get_user_jar())) ;
 
 		my $st = $pc->ServerType() ;
 		if ((($st eq "shared")&&(! $o->get_java_config('SHARED_JVM')))||
@@ -628,7 +636,10 @@ sub load_jdat {
 	my $data_idx = scalar(@{$o->{ILSM}->{data}}) ;
 	push @{$o->{ILSM}->{data}}, $d ;
 	
-	my $re = '[\w.\$\[;]+' ;
+	# The original regexp didn't match anymore under the debugger...
+	# Very strange indeed...
+	# my $re = '[\w.\$\[;]+' ;
+	my $re = '.+' ;
 
 	my $idx = 0 ;
 	my $current_class = undef ;
@@ -641,7 +652,7 @@ sub load_jdat {
 	}
 	foreach my $line (@{$lines}){
 		chomp($line) ;
-		if ($line =~ /^class ($re) ($re|null)$/){
+		if ($line =~ /^class ($re) ($re)$/){
 			# We found a class definition
 			my $java_class = $1 ;
 			my $parent_java_class = $2 ;
