@@ -3,10 +3,12 @@ package Inline::Java::Class ;
 use strict ;
 use Carp ;
 
-$Inline::Java::Class::VERSION = '0.49' ;
+$Inline::Java::Class::VERSION = '0.50' ;
 
 $Inline::Java::Class::MAX_SCORE = 10 ;
 
+# There is no use supporting exponent notation for integer types since
+# Jave does not support it without casting.
 my $INT_RE = '^[+-]?\d+$' ;
 my $FLOAT_RE = '^([+-]?)(?=\d|\.\d)\d*(\.\d*)?([Ee]([+-]?\d+))?$' ;
 
@@ -26,33 +28,29 @@ my $RANGE = {
 		MAX => 2147483647,
 		MIN => -2147483648,
 	},
-	'java.lang.Long' => {
-		REGEXP => $INT_RE,
-		MAX => 2147483647,
-		MIN => -2147483648,
-		# MAX => 9223372036854775807,
-		# MIN => -9223372036854775808,
-	},
 	'java.lang.Float' => {
 		REGEXP => $FLOAT_RE,
 		MAX => 3.4028235e38,
 		MIN => -3.4028235e38,
-		POS_MIN	=> 1.4e-45,
-		NEG_MAX => -1.4e-45,
+		# POS_MIN	=> 1.4e-45,
+		# NEG_MAX => -1.4e-45,
+	},
+	'java.lang.Long' => {
+		REGEXP => $INT_RE,
+		# MAX => 9223372036854775807,
+		# MIN => -9223372036854775808,
 	},
 	'java.lang.Double' => {
 		REGEXP => $FLOAT_RE,
-		MAX => 3.4028235e38,
-		MIN => -3.4028235e38,
-		# MAX => 1.7976931348623157e308,
-		# MIN => -1.7976931348623157e308,
-		POS_MIN => 4.9e-324,
-		NEG_MAX => -4.9e-324,
+		# MAX => 1.79e308,
+		# MIN => -1.79e308,
+		# POS_MIN => 4.9e-324,
+		# NEG_MAX => -4.9e-324,
 	},
 } ;
 $RANGE->{byte} = $RANGE->{'java.lang.Byte'} ;
 $RANGE->{short} = $RANGE->{'java.lang.Short'} ;
-$RANGE->{int} = $RANGE->{'java.lang.Integer'} ;
+$RANGE->{'int'} = $RANGE->{'java.lang.Integer'} ;
 $RANGE->{long} = $RANGE->{'java.lang.Long'} ;
 $RANGE->{float} = $RANGE->{'java.lang.Float'} ;
 $RANGE->{double} = $RANGE->{'java.lang.Double'} ;
@@ -163,7 +161,7 @@ sub CastArgument {
 						croak "Can't convert $arg to object $proto" ;
 					}
 				}
-				else{
+				else {
 					# Here we got a scalar
 					# Here we allow scalars to be passed in place of java.lang.Object
 					# They will wrapped on the Java side.
@@ -186,15 +184,21 @@ sub CastArgument {
 			my $re = $RANGE->{$proto}->{REGEXP} ;
 			my $min = $RANGE->{$proto}->{MIN} ;
 			my $max = $RANGE->{$proto}->{MAX} ;
-			Inline::Java::debug(4, "min = $min, max = $max, val = $arg") ;
+			Inline::Java::debug(4, 
+				"min = " . ($min || '') . ", " . 
+				"max = " . ($max || '') . ", " .
+				"val = $arg") ;
 			if ($arg =~ /$re/){
-				if (($arg >= $min)&&($arg <= $max)){
+				if (((! defined($min))||($arg >= $min))&&
+					((! defined($max))||($arg <= $max))){
 					# number is a pretty precise match, but it's still
 					# guessing amongst the numeric types
 					return ($arg, 5.5) ;
 				}
 				croak "$arg out of range for type $proto" ;
 			}
+			elsif ($arg =~ /$FLOAT_RE/){
+			}
 			croak "Can't convert $arg to $proto" ;
 		}
 		elsif (ClassIsChar($proto)){
