@@ -25,7 +25,9 @@ public class InlineJavaPerlInterpreter extends InlineJavaPerlCaller {
 	protected InlineJavaPerlInterpreter() throws InlineJavaPerlException, InlineJavaException {
 		init() ;
 
+		InlineJavaUtils.debug(2, "constructing perl interpreter") ;
 		construct() ;
+		InlineJavaUtils.debug(2, "perl interpreter constructed") ;
 
 		if (! libperl_so.equals("")){
 			evalNoReturn("require DynaLoader ;") ;
@@ -42,8 +44,12 @@ public class InlineJavaPerlInterpreter extends InlineJavaPerlCaller {
 		if (instance == null){
 			// Here we create a temporary InlineJavaServer instance in order to be able to instanciate
 			// ourselves. When we create InlineJavaPerlInterpreter, the instance will be overriden.
-			InlineJavaServer.jni_main(0) ;
+			InlineJavaUtils.debug(2, "creating temporary JNI InlineJavaServer") ;
+			InlineJavaServer.jni_main(InlineJavaUtils.debug) ;
+			InlineJavaUtils.debug(2, "temporary JNI InlineJavaServer created") ;
+			InlineJavaUtils.debug(2, "creating InlineJavaPerlInterpreter") ;
 			instance = new InlineJavaPerlInterpreter() ;
+			InlineJavaUtils.debug(2, "InlineJavaPerlInterpreter created") ;
 		}
 		return instance ;
 	}
@@ -70,6 +76,7 @@ public class InlineJavaPerlInterpreter extends InlineJavaPerlCaller {
 				// Load the PerlInterpreter shared object
 				InlineJavaUtils.debug(2, "loading shared library " + perlinterpreter_so) ;
 				System.load(perlinterpreter_so) ;
+				InlineJavaUtils.debug(2, "shared library " + perlinterpreter_so + " loaded") ;
 
 				libperl_so = GetBundle().getString("inline_java_libperl_so") ;
 
